# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_characterization import ShopifyComplianceCharacterization

class TestShopifyComplianceCharacterization(unittest.TestCase):
    """ShopifyComplianceCharacterization unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceCharacterization:
        """Test ShopifyComplianceCharacterization
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceCharacterization`
        """
        model = ShopifyComplianceCharacterization()
        if include_optional:
            return ShopifyComplianceCharacterization(
                inputs = {
                    'key' : None
                    },
                intent = '',
                notes = [
                    ''
                    ],
                retained_tables = [
                    ''
                    ],
                scope = '',
                summary = '',
                targets = [
                    neurograph.v1.models.shopify/compliance_characterization_target.shopify.ComplianceCharacterizationTarget(
                        action = '', 
                        description = '', 
                        error = '', 
                        query = '', 
                        rows_affected = 56, 
                        status = '', 
                        table = '', )
                    ]
            )
        else:
            return ShopifyComplianceCharacterization(
        )
        """

    def testShopifyComplianceCharacterization(self):
        """Test ShopifyComplianceCharacterization"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
