# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_category_performance_data import ReportingCategoryPerformanceData

class TestReportingCategoryPerformanceData(unittest.TestCase):
    """ReportingCategoryPerformanceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCategoryPerformanceData:
        """Test ReportingCategoryPerformanceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCategoryPerformanceData`
        """
        model = ReportingCategoryPerformanceData()
        if include_optional:
            return ReportingCategoryPerformanceData(
                categories = [
                    neurograph.v1.models.reporting/category_performance_row.reporting.CategoryPerformanceRow(
                        account_avg_affinity = 1.337, 
                        account_avg_conv_rate = 1.337, 
                        account_avg_purchases = 1.337, 
                        account_purchase_pct = 1.337, 
                        affinity_delta = 1.337, 
                        aov = 1.337, 
                        avg_affinity_score = 1.337, 
                        category_name = '', 
                        conv_rate_delta = 1.337, 
                        conversion_rate = 1.337, 
                        engagement_level = '', 
                        is_top_category = True, 
                        persona_purchase_pct = 1.337, 
                        purchase_pct_delta = 1.337, 
                        purchases = 56, 
                        relative_performance = 1.337, 
                        rpv = 1.337, 
                        total_visitors = 56, )
                    ],
                displayed_categories = 56,
                total_categories = 56
            )
        else:
            return ReportingCategoryPerformanceData(
        )
        """

    def testReportingCategoryPerformanceData(self):
        """Test ReportingCategoryPerformanceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
