# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_deletion_queue_list_response import ShopifyComplianceDeletionQueueListResponse

class TestShopifyComplianceDeletionQueueListResponse(unittest.TestCase):
    """ShopifyComplianceDeletionQueueListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceDeletionQueueListResponse:
        """Test ShopifyComplianceDeletionQueueListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceDeletionQueueListResponse`
        """
        model = ShopifyComplianceDeletionQueueListResponse()
        if include_optional:
            return ShopifyComplianceDeletionQueueListResponse(
                data = [
                    neurograph.v1.models.shopify/compliance_deletion_queue_summary.shopify.ComplianceDeletionQueueSummary(
                        approved_at = '', 
                        client_deletion_status = '', 
                        client_id = '', 
                        client_name = '', 
                        client_uid = '', 
                        id = 56, 
                        myshopify_domain = '', 
                        org_id = '', 
                        org_name = '', 
                        org_uid = '', 
                        queue_status = '', 
                        request_type = '', 
                        requested_at = '', 
                        review_status = '', 
                        scheduled_purge_at = '', 
                        shop_domain = '', 
                        shop_id = 56, )
                    ],
                error = '',
                query = neurograph.v1.models.shopify/compliance_deletion_queue_query.shopify.ComplianceDeletionQueueQuery(
                    limit = 56, 
                    offset = 56, ),
                total_rows = 56
            )
        else:
            return ShopifyComplianceDeletionQueueListResponse(
        )
        """

    def testShopifyComplianceDeletionQueueListResponse(self):
        """Test ShopifyComplianceDeletionQueueListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
