# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.opportunities_opportunity_list_response import OpportunitiesOpportunityListResponse

class TestOpportunitiesOpportunityListResponse(unittest.TestCase):
    """OpportunitiesOpportunityListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpportunitiesOpportunityListResponse:
        """Test OpportunitiesOpportunityListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpportunitiesOpportunityListResponse`
        """
        model = OpportunitiesOpportunityListResponse()
        if include_optional:
            return OpportunitiesOpportunityListResponse(
                data = [
                    neurograph.v1.models.opportunities/opportunity_response.opportunities.OpportunityResponse(
                        action_description = '', 
                        category = '', 
                        client_id = '', 
                        comparison_context = '', 
                        comparison_stat = '', 
                        comparison_type = '', 
                        description = '', 
                        display_order = 56, 
                        effort_level = '', 
                        error = '', 
                        id = '', 
                        name = '', 
                        organization_id = '', 
                        priority_tier = '', 
                        roi_metric = '', 
                        roi_progress = 56, 
                        roi_value = '', 
                        status = '', 
                        subtitle = '', 
                        ts_created = '', 
                        ts_updated = '', )
                    ],
                error = '',
                limit = 56,
                page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return OpportunitiesOpportunityListResponse(
        )
        """

    def testOpportunitiesOpportunityListResponse(self):
        """Test OpportunitiesOpportunityListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
