# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_rollup_debug_info import ReportingDailyRollupDebugInfo

class TestReportingDailyRollupDebugInfo(unittest.TestCase):
    """ReportingDailyRollupDebugInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyRollupDebugInfo:
        """Test ReportingDailyRollupDebugInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyRollupDebugInfo`
        """
        model = ReportingDailyRollupDebugInfo()
        if include_optional:
            return ReportingDailyRollupDebugInfo(
                activity_window_days = 56,
                bq_analytics_project = '',
                bq_project = '',
                client_uid = '',
                cohort_start_date = '',
                customers_table = '',
                end_date = '',
                orders_table = '',
                org_uid = '',
                queries = [
                    neurograph.v1.models.reporting/debug_query.reporting.DebugQuery(
                        error = '', 
                        name = '', 
                        sql = '', )
                    ],
                query_time_ms = 56,
                start_date = ''
            )
        else:
            return ReportingDailyRollupDebugInfo(
        )
        """

    def testReportingDailyRollupDebugInfo(self):
        """Test ReportingDailyRollupDebugInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
