# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ShopifyComplianceRequestSummary(BaseModel):
    """
    ShopifyComplianceRequestSummary
    """ # noqa: E501
    client_deletion_status: Optional[StrictStr] = None
    client_id: Optional[StrictStr] = None
    client_name: Optional[StrictStr] = None
    client_uid: Optional[StrictStr] = None
    completed_at: Optional[StrictStr] = None
    customer_email: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    id: Optional[StrictInt] = None
    myshopify_domain: Optional[StrictStr] = None
    org_id: Optional[StrictStr] = None
    org_name: Optional[StrictStr] = None
    org_uid: Optional[StrictStr] = None
    queue_id: Optional[StrictInt] = None
    queue_status: Optional[StrictStr] = None
    requested_at: Optional[StrictStr] = None
    review_status: Optional[StrictStr] = None
    shop_domain: Optional[StrictStr] = None
    shop_id: Optional[StrictInt] = None
    status: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["client_deletion_status", "client_id", "client_name", "client_uid", "completed_at", "customer_email", "customer_id", "id", "myshopify_domain", "org_id", "org_name", "org_uid", "queue_id", "queue_status", "requested_at", "review_status", "shop_domain", "shop_id", "status", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_deletion_status": obj.get("client_deletion_status"),
            "client_id": obj.get("client_id"),
            "client_name": obj.get("client_name"),
            "client_uid": obj.get("client_uid"),
            "completed_at": obj.get("completed_at"),
            "customer_email": obj.get("customer_email"),
            "customer_id": obj.get("customer_id"),
            "id": obj.get("id"),
            "myshopify_domain": obj.get("myshopify_domain"),
            "org_id": obj.get("org_id"),
            "org_name": obj.get("org_name"),
            "org_uid": obj.get("org_uid"),
            "queue_id": obj.get("queue_id"),
            "queue_status": obj.get("queue_status"),
            "requested_at": obj.get("requested_at"),
            "review_status": obj.get("review_status"),
            "shop_domain": obj.get("shop_domain"),
            "shop_id": obj.get("shop_id"),
            "status": obj.get("status"),
            "type": obj.get("type")
        })
        return _obj


