# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_price_tolerance_data import ReportingPriceToleranceData

class TestReportingPriceToleranceData(unittest.TestCase):
    """ReportingPriceToleranceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPriceToleranceData:
        """Test ReportingPriceToleranceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPriceToleranceData`
        """
        model = ReportingPriceToleranceData()
        if include_optional:
            return ReportingPriceToleranceData(
                price_distribution = [
                    neurograph.v1.models.reporting/price_bucket.reporting.PriceBucket(
                        is_top_bucket = True, 
                        order_count = 56, 
                        percentage = 1.337, 
                        price_bucket = '', 
                        price_bucket_label = '', )
                    ],
                willingness_to_pay_premium = ''
            )
        else:
            return ReportingPriceToleranceData(
        )
        """

    def testReportingPriceToleranceData(self):
        """Test ReportingPriceToleranceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
