# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_client_signal_totals import SignalClientSignalTotals

class TestSignalClientSignalTotals(unittest.TestCase):
    """SignalClientSignalTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalClientSignalTotals:
        """Test SignalClientSignalTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalClientSignalTotals`
        """
        model = SignalClientSignalTotals()
        if include_optional:
            return SignalClientSignalTotals(
                conversions = neurograph.v1.models.signal/conversion_summary.signal.ConversionSummary(
                    api_success_rate = 1.337, 
                    avg_data_completeness = 1.337, 
                    new_customers = 56, 
                    predicted_revenue = 1.337, 
                    prediction_uplift_pct = 1.337, 
                    returning_customers = 56, 
                    returning_pct = 1.337, 
                    total_purchases = 56, 
                    total_revenue = 1.337, ),
                intent = neurograph.v1.models.signal/intent_summary.signal.IntentSummary(
                    avg_high_engagement = 1.337, 
                    avg_low_engagement = 1.337, 
                    avg_medium_engagement = 1.337, 
                    high_conversion_rate = 1.337, 
                    low_conversion_rate = 1.337, 
                    medium_conversion_rate = 1.337, 
                    total_high = 56, 
                    total_low = 56, 
                    total_medium = 56, )
            )
        else:
            return SignalClientSignalTotals(
        )
        """

    def testSignalClientSignalTotals(self):
        """Test SignalClientSignalTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
