# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.client_metadata_api import ClientMetadataApi


class TestClientMetadataApi(unittest.TestCase):
    """ClientMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClientMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_client_metadata_client_id_delete(self) -> None:
        """Test case for api_v1_client_metadata_client_id_delete

        Delete a metadata row
        """
        pass

    def test_api_v1_client_metadata_client_id_get(self) -> None:
        """Test case for api_v1_client_metadata_client_id_get

        Get client metadata rows
        """
        pass

    def test_api_v1_client_metadata_client_id_post(self) -> None:
        """Test case for api_v1_client_metadata_client_id_post

        Upsert a client metadata row
        """
        pass

    def test_api_v1_client_metadata_org_uid_client_uid_get(self) -> None:
        """Test case for api_v1_client_metadata_org_uid_client_uid_get

        Get client metadata by organization UID and client UID
        """
        pass


if __name__ == '__main__':
    unittest.main()
