# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse

class TestReportingDailyMetricsResponse(unittest.TestCase):
    """ReportingDailyMetricsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyMetricsResponse:
        """Test ReportingDailyMetricsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyMetricsResponse`
        """
        model = ReportingDailyMetricsResponse()
        if include_optional:
            return ReportingDailyMetricsResponse(
                cached = True,
                data = [
                    neurograph.v1.models.reporting/daily_metric.reporting.DailyMetric(
                        aov = 1.337, 
                        avg_ltv_original = 1.337, 
                        cohort_customers = 56, 
                        conversion_rate = 1.337, 
                        customer_conversion_rate = 1.337, 
                        customers_with_purchases = 56, 
                        data_quality_flag = '', 
                        iqr_avg_ltv = 1.337, 
                        ltv_outlier_count = 56, 
                        median_ltv = 1.337, 
                        p25_ltv = 1.337, 
                        p75_ltv = 1.337, 
                        period_revenue = 1.337, 
                        persona_name = '', 
                        persona_seed_id = '', 
                        rpv = 1.337, 
                        rpv_iqr = 1.337, 
                        rpv_median = 1.337, 
                        rpv_outlier_count = 56, 
                        rpv_p25 = 1.337, 
                        rpv_p75 = 1.337, 
                        rpv_trimmed = 1.337, 
                        rpv_winsorized = 1.337, 
                        total_customers = 56, 
                        total_visitors = 56, 
                        trimmed_avg_ltv = 1.337, 
                        visitor_conversion_rate = 1.337, 
                        visitors_with_purchases = 56, 
                        winsorized_avg_ltv = 1.337, )
                    ],
                debug_info = neurograph.v1.models.reporting/daily_rollup_debug_info.reporting.DailyRollupDebugInfo(
                    activity_window_days = 56, 
                    bq_analytics_project = '', 
                    bq_project = '', 
                    client_uid = '', 
                    cohort_start_date = '', 
                    customers_table = '', 
                    end_date = '', 
                    orders_table = '', 
                    org_uid = '', 
                    queries = [
                        neurograph.v1.models.reporting/debug_query.reporting.DebugQuery(
                            error = '', 
                            name = '', 
                            sql = '', )
                        ], 
                    query_time_ms = 56, 
                    start_date = '', ),
                error = '',
                query_time_ms = 56
            )
        else:
            return ReportingDailyMetricsResponse(
        )
        """

    def testReportingDailyMetricsResponse(self):
        """Test ReportingDailyMetricsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
