# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_signal_overview_totals import SignalSignalOverviewTotals

class TestSignalSignalOverviewTotals(unittest.TestCase):
    """SignalSignalOverviewTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalSignalOverviewTotals:
        """Test SignalSignalOverviewTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalSignalOverviewTotals`
        """
        model = SignalSignalOverviewTotals()
        if include_optional:
            return SignalSignalOverviewTotals(
                avg_match_rate_pct = 1.337,
                conversions = neurograph.v1.models.signal/conversion_totals.signal.ConversionTotals(
                    api_success_rate = 1.337, 
                    avg_data_completeness = 1.337, 
                    persona_coverage = 1.337, 
                    total_conversions = 56, 
                    total_pageview_conversions = 56, 
                    total_purchase_conversions = 56, 
                    visitor_id_coverage = 1.337, ),
                intent_distribution = neurograph.v1.models.signal/intent_distribution.signal.IntentDistribution(
                    high_intent = 56, 
                    high_pct = 1.337, 
                    low_intent = 56, 
                    low_pct = 1.337, 
                    medium_intent = 56, 
                    medium_pct = 1.337, ),
                total_visitors = 56,
                total_with_hem = 56
            )
        else:
            return SignalSignalOverviewTotals(
        )
        """

    def testSignalSignalOverviewTotals(self):
        """Test SignalSignalOverviewTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
