# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData

class TestReportingGeographicDistributionData(unittest.TestCase):
    """ReportingGeographicDistributionData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingGeographicDistributionData:
        """Test ReportingGeographicDistributionData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingGeographicDistributionData`
        """
        model = ReportingGeographicDistributionData()
        if include_optional:
            return ReportingGeographicDistributionData(
                metro_areas = [
                    neurograph.v1.models.reporting/metro_area.reporting.MetroArea(
                        account_concentration_pct = 1.337, 
                        concentration_pct = 1.337, 
                        customer_count = 56, 
                        delta = 1.337, 
                        is_filler = True, 
                        metro = '', 
                        rank = 56, 
                        relative_delta_pct = 1.337, 
                        state = '', )
                    ],
                other_markets = neurograph.v1.models.reporting/other_markets.reporting.OtherMarkets(
                    concentration_pct = 1.337, 
                    count = 56, 
                    customer_count = 56, ),
                total_metro_count = 56
            )
        else:
            return ReportingGeographicDistributionData(
        )
        """

    def testReportingGeographicDistributionData(self):
        """Test ReportingGeographicDistributionData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
