# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_purchase_cycle_data import ReportingPurchaseCycleData

class TestReportingPurchaseCycleData(unittest.TestCase):
    """ReportingPurchaseCycleData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPurchaseCycleData:
        """Test ReportingPurchaseCycleData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPurchaseCycleData`
        """
        model = ReportingPurchaseCycleData()
        if include_optional:
            return ReportingPurchaseCycleData(
                new_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                    count = 56, 
                    cycle_days = 56, 
                    display_value = '', 
                    median_days = 56, 
                    tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                        fast = 56, 
                        slow = 56, 
                        typical = 56, ), ),
                returning_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                    count = 56, 
                    cycle_days = 56, 
                    display_value = '', 
                    median_days = 56, 
                    tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                        fast = 56, 
                        slow = 56, 
                        typical = 56, ), ),
                summary = neurograph.v1.models.reporting/cycle_summary.reporting.CycleSummary(
                    categories = neurograph.v1.models.reporting/category_summary.reporting.CategorySummary(
                        engaged = 56, 
                        total = 56, ), 
                    last_purchase_days_ago = 56, 
                    total_customers = 56, )
            )
        else:
            return ReportingPurchaseCycleData(
        )
        """

    def testReportingPurchaseCycleData(self):
        """Test ReportingPurchaseCycleData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
