# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.shopify_compliance_deletion_queue_query import ShopifyComplianceDeletionQueueQuery
from neurograph.v1.models.shopify_compliance_request_summary import ShopifyComplianceRequestSummary
from typing import Optional, Set
from typing_extensions import Self

class ShopifyComplianceRequestListResponse(BaseModel):
    """
    ShopifyComplianceRequestListResponse
    """ # noqa: E501
    data: Optional[List[ShopifyComplianceRequestSummary]] = None
    error: Optional[StrictStr] = None
    query: Optional[ShopifyComplianceDeletionQueueQuery] = None
    total_rows: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["data", "error", "query", "total_rows"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict['data'] = _items
        # override the default output from pydantic by calling `to_dict()` of query
        if self.query:
            _dict['query'] = self.query.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ShopifyComplianceRequestListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data": [ShopifyComplianceRequestSummary.from_dict(_item) for _item in obj["data"]] if obj.get("data") is not None else None,
            "error": obj.get("error"),
            "query": ShopifyComplianceDeletionQueueQuery.from_dict(obj["query"]) if obj.get("query") is not None else None,
            "total_rows": obj.get("total_rows")
        })
        return _obj


