# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_product_affinity_row import ReportingProductAffinityRow

class TestReportingProductAffinityRow(unittest.TestCase):
    """ReportingProductAffinityRow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingProductAffinityRow:
        """Test ReportingProductAffinityRow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingProductAffinityRow`
        """
        model = ReportingProductAffinityRow()
        if include_optional:
            return ReportingProductAffinityRow(
                avg_engagement_score = 1.337,
                avg_lifetime_value = 1.337,
                avg_view_count = 1.337,
                client_partition_key = '',
                confidence_level = 56,
                conversion_rate = 1.337,
                entity_id = '',
                normalized_affinity_score = 1.337,
                partition_date = '',
                product_handle = '',
                product_id = '',
                product_name = '',
                product_type = '',
                raw_affinity_score = 1.337,
                score_penalty = 1.337,
                total_conversions = 56,
                total_visitors = 56,
                weighted_conversion_score = 1.337
            )
        else:
            return ReportingProductAffinityRow(
        )
        """

    def testReportingProductAffinityRow(self):
        """Test ReportingProductAffinityRow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
