# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_compliance_deletion_queue_detail_response import ShopifyComplianceDeletionQueueDetailResponse

class TestShopifyComplianceDeletionQueueDetailResponse(unittest.TestCase):
    """ShopifyComplianceDeletionQueueDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyComplianceDeletionQueueDetailResponse:
        """Test ShopifyComplianceDeletionQueueDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyComplianceDeletionQueueDetailResponse`
        """
        model = ShopifyComplianceDeletionQueueDetailResponse()
        if include_optional:
            return ShopifyComplianceDeletionQueueDetailResponse(
                data = neurograph.v1.models.shopify/compliance_deletion_queue_detail.shopify.ComplianceDeletionQueueDetail(
                    actions = [
                        neurograph.v1.models.shopify/compliance_action.shopify.ComplianceAction(
                            action_type = '', 
                            details = [
                                56
                                ], 
                            executed_at = '', 
                            id = 56, 
                            status = '', )
                        ], 
                    characterization = neurograph.v1.models.shopify/compliance_characterization.shopify.ComplianceCharacterization(
                        inputs = {
                            'key' : None
                            }, 
                        intent = '', 
                        notes = [
                            ''
                            ], 
                        retained_tables = [
                            ''
                            ], 
                        scope = '', 
                        summary = '', 
                        targets = [
                            neurograph.v1.models.shopify/compliance_characterization_target.shopify.ComplianceCharacterizationTarget(
                                action = '', 
                                description = '', 
                                error = '', 
                                query = '', 
                                rows_affected = 56, 
                                status = '', 
                                table = '', )
                            ], ), 
                    recommendation = neurograph.v1.models.shopify/compliance_recommendation.shopify.ComplianceRecommendation(
                        bigquery_scopes = [
                            ''
                            ], 
                        core_tables = [
                            ''
                            ], 
                        identifiers = neurograph.v1.models.shopify/compliance_identifiers.shopify.ComplianceIdentifiers(
                            client_id = '', 
                            client_partition_keys = [
                                ''
                                ], 
                            client_uid = '', 
                            myshopify_domain = '', 
                            org_id = '', 
                            org_uid = '', 
                            shop_domain = '', 
                            shop_id = 56, ), 
                        immediate_actions = [
                            ''
                            ], ), 
                    request = neurograph.v1.models.shopify/compliance_request_detail.shopify.ComplianceRequestDetail(
                        completed_at = '', 
                        id = 56, 
                        request_payload = [
                            56
                            ], 
                        requested_at = '', 
                        result_summary = [
                            56
                            ], 
                        status = '', 
                        type = '', ), 
                    summary = neurograph.v1.models.shopify/compliance_deletion_queue_summary.shopify.ComplianceDeletionQueueSummary(
                        approved_at = '', 
                        client_deletion_status = '', 
                        client_id = '', 
                        client_name = '', 
                        client_uid = '', 
                        id = 56, 
                        myshopify_domain = '', 
                        org_id = '', 
                        org_name = '', 
                        org_uid = '', 
                        queue_status = '', 
                        request_type = '', 
                        requested_at = '', 
                        review_status = '', 
                        scheduled_purge_at = '', 
                        shop_domain = '', 
                        shop_id = 56, ), ),
                error = ''
            )
        else:
            return ShopifyComplianceDeletionQueueDetailResponse(
        )
        """

    def testShopifyComplianceDeletionQueueDetailResponse(self):
        """Test ShopifyComplianceDeletionQueueDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
