# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_get_many_response import ClientGetManyResponse

class TestClientGetManyResponse(unittest.TestCase):
    """ClientGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientGetManyResponse:
        """Test ClientGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientGetManyResponse`
        """
        model = ClientGetManyResponse()
        if include_optional:
            return ClientGetManyResponse(
                data = [
                    neurograph.v1.models.client/client.client.Client(
                        id = '', 
                        is_active = True, 
                        name = '', 
                        org_id = '', 
                        personas_reviewed = True, 
                        pixel_snippets = [
                            neurograph.v1.models.db/pixel_snippet.db.PixelSnippet(
                                id = 56, 
                                name = '', 
                                snippet = '', )
                            ], 
                        ts_created = 56, 
                        ts_updated = 56, 
                        uid = '', 
                        urls = [
                            neurograph.v1.models.db/client_url.db.ClientUrl(
                                client_id = 'cli_12345', 
                                customer_environment = '', 
                                id = 56, 
                                is_active = True, 
                                url = 'example.com', )
                            ], )
                    ],
                error = '',
                query = neurograph.v1.models.client/query.client.Query(
                    limit = 56, 
                    offset = 56, 
                    org_id = '', 
                    uid = '', ),
                total_rows = 56
            )
        else:
            return ClientGetManyResponse(
        )
        """

    def testClientGetManyResponse(self):
        """Test ClientGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
