# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.shopify_api import ShopifyApi


class TestShopifyApi(unittest.TestCase):
    """ShopifyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShopifyApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_shopify_stores_client_client_id_get(self) -> None:
        """Test case for api_v1_shopify_stores_client_client_id_get

        Get Shopify store for client
        """
        pass

    def test_api_v1_shopify_stores_shop_id_associate_delete(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_associate_delete

        Remove Shopify store association
        """
        pass

    def test_api_v1_shopify_stores_shop_id_associate_post(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_associate_post

        Associate unmatched Shopify store to a client
        """
        pass

    def test_api_v1_shopify_stores_shop_id_get(self) -> None:
        """Test case for api_v1_shopify_stores_shop_id_get

        Get Shopify store by ID
        """
        pass

    def test_api_v1_shopify_stores_unmatched_get(self) -> None:
        """Test case for api_v1_shopify_stores_unmatched_get

        List unmatched Shopify stores
        """
        pass


if __name__ == '__main__':
    unittest.main()
