# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_response import OrganizationsGammaThemeResponse

class TestOrganizationsGammaThemeResponse(unittest.TestCase):
    """OrganizationsGammaThemeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeResponse:
        """Test OrganizationsGammaThemeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeResponse`
        """
        model = OrganizationsGammaThemeResponse()
        if include_optional:
            return OrganizationsGammaThemeResponse(
                error = '',
                success = True,
                theme = neurograph.v1.models.organizations/gamma_theme_settings.organizations.GammaThemeSettings(
                    colors = neurograph.v1.models.colors.colors(), 
                    design = neurograph.v1.models.design.design(), 
                    fonts = neurograph.v1.models.fonts.fonts(), 
                    reasoning = '', )
            )
        else:
            return OrganizationsGammaThemeResponse(
        )
        """

    def testOrganizationsGammaThemeResponse(self):
        """Test OrganizationsGammaThemeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
