# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_get_unmatched_stores_response import ShopifyGetUnmatchedStoresResponse

class TestShopifyGetUnmatchedStoresResponse(unittest.TestCase):
    """ShopifyGetUnmatchedStoresResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyGetUnmatchedStoresResponse:
        """Test ShopifyGetUnmatchedStoresResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyGetUnmatchedStoresResponse`
        """
        model = ShopifyGetUnmatchedStoresResponse()
        if include_optional:
            return ShopifyGetUnmatchedStoresResponse(
                data = [
                    neurograph.v1.models.shopify/store_summary.shopify.StoreSummary(
                        client_id = '', 
                        domain = '', 
                        id = 56, 
                        ingested_at = '', 
                        myshopify_domain = '', 
                        name = '', 
                        shopify_updated_at_ms = 56, 
                        updated_at_ms = 56, )
                    ],
                error = '',
                query = neurograph.v1.models.shopify/store_query.shopify.StoreQuery(
                    limit = 56, 
                    offset = 56, ),
                total_rows = 56
            )
        else:
            return ShopifyGetUnmatchedStoresResponse(
        )
        """

    def testShopifyGetUnmatchedStoresResponse(self):
        """Test ShopifyGetUnmatchedStoresResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
