# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.organization_api import OrganizationApi


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_organizations_branding_generate_gamma_theme_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_gamma_theme_post

        Generate Gamma theme settings from brand colors using AI
        """
        pass

    def test_api_v1_organizations_branding_generate_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_post

        Generate branding from screenshot using AI
        """
        pass

    def test_api_v1_organizations_branding_generate_screenshot_url_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_screenshot_url_post

        Generate signed ScreenshotOne URL for website
        """
        pass

    def test_api_v1_organizations_branding_generate_tokens_post(self) -> None:
        """Test case for api_v1_organizations_branding_generate_tokens_post

        Generate Theme Tokens
        """
        pass

    def test_api_v1_organizations_branding_post(self) -> None:
        """Test case for api_v1_organizations_branding_post

        Set an Organization's Branding
        """
        pass

    def test_api_v1_organizations_branding_presets_apply_post(self) -> None:
        """Test case for api_v1_organizations_branding_presets_apply_post

        Apply Theme Preset to Organization Branding
        """
        pass

    def test_api_v1_organizations_branding_presets_category_category_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_category_category_get

        Get Theme Presets by Category
        """
        pass

    def test_api_v1_organizations_branding_presets_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_get

        Get Theme Presets
        """
        pass

    def test_api_v1_organizations_branding_presets_id_delete(self) -> None:
        """Test case for api_v1_organizations_branding_presets_id_delete

        Delete Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_post(self) -> None:
        """Test case for api_v1_organizations_branding_presets_post

        Create Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_put(self) -> None:
        """Test case for api_v1_organizations_branding_presets_put

        Update Theme Preset
        """
        pass

    def test_api_v1_organizations_branding_presets_recommendations_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_recommendations_get

        Get Preset Recommendations
        """
        pass

    def test_api_v1_organizations_branding_presets_search_get(self) -> None:
        """Test case for api_v1_organizations_branding_presets_search_get

        Search Theme Presets
        """
        pass

    def test_api_v1_organizations_branding_preview_post(self) -> None:
        """Test case for api_v1_organizations_branding_preview_post

        Preview Branding
        """
        pass

    def test_api_v1_organizations_branding_rollback_post(self) -> None:
        """Test case for api_v1_organizations_branding_rollback_post

        Rollback Branding to Previous Version
        """
        pass

    def test_api_v1_organizations_branding_test_accessibility_post(self) -> None:
        """Test case for api_v1_organizations_branding_test_accessibility_post

        Test Branding Accessibility
        """
        pass

    def test_api_v1_organizations_branding_validate_post(self) -> None:
        """Test case for api_v1_organizations_branding_validate_post

        Validate Branding Colors
        """
        pass

    def test_api_v1_organizations_get(self) -> None:
        """Test case for api_v1_organizations_get

        Get Organizations
        """
        pass

    def test_api_v1_organizations_id_branding_delete(self) -> None:
        """Test case for api_v1_organizations_id_branding_delete

        Delete an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_get

        Get an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_history_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_history_get

        Get Branding History
        """
        pass

    def test_api_v1_organizations_id_branding_history_version_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_history_version_get

        Get Specific Branding Version
        """
        pass

    def test_api_v1_organizations_id_branding_put(self) -> None:
        """Test case for api_v1_organizations_id_branding_put

        Update an Organization's Branding
        """
        pass

    def test_api_v1_organizations_id_branding_tokens_get(self) -> None:
        """Test case for api_v1_organizations_id_branding_tokens_get

        Get Cached Branding Tokens
        """
        pass

    def test_api_v1_organizations_org_id_get(self) -> None:
        """Test case for api_v1_organizations_org_id_get

        Get Organization by ID or UID
        """
        pass

    def test_api_v1_organizations_org_id_users_get(self) -> None:
        """Test case for api_v1_organizations_org_id_users_get

        Organization's assigned users and their permissions
        """
        pass

    def test_api_v1_organizations_post(self) -> None:
        """Test case for api_v1_organizations_post

        Create an Organization
        """
        pass

    def test_api_v1_organizations_put(self) -> None:
        """Test case for api_v1_organizations_put

        Update an Organization
        """
        pass

    def test_api_v1_organizations_workbench_post(self) -> None:
        """Test case for api_v1_organizations_workbench_post

        Set Organization's Workbench Version
        """
        pass


if __name__ == '__main__':
    unittest.main()
