# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.shopify_get_store_response import ShopifyGetStoreResponse

class TestShopifyGetStoreResponse(unittest.TestCase):
    """ShopifyGetStoreResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopifyGetStoreResponse:
        """Test ShopifyGetStoreResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopifyGetStoreResponse`
        """
        model = ShopifyGetStoreResponse()
        if include_optional:
            return ShopifyGetStoreResponse(
                data = neurograph.v1.models.shopify/store_detail.shopify.StoreDetail(
                    client_id = '', 
                    domain = '', 
                    id = 56, 
                    ingested_at = '', 
                    myshopify_domain = '', 
                    name = '', 
                    shopify_updated_at_ms = 56, 
                    updated_at_ms = 56, ),
                error = ''
            )
        else:
            return ShopifyGetStoreResponse(
        )
        """

    def testShopifyGetStoreResponse(self):
        """Test ShopifyGetStoreResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
